==> react-d3-0.1.1.tgz: package/barchart.js <==
/** @jsx React.DOM */
var React = require('react');
var d3 = require('d3');
var Chart = require('./common').Chart;
var _ = require('lodash');


var Bar = React.createClass({displayName: 'Bar',

  propTypes: {
    fill: React.PropTypes.string,
    width: React.PropTypes.number,
    height: React.PropTypes.number,
    offset: React.PropTypes.number
  },

  getDefaultProps: function() {
    return {
      offset: 0
    }
  },

  render: function() {
    return (
      React.createElement("rect", {
        fill: this.props.fill, 
        width: this.props.width, 
        height: this.props.height, 
        x: this.props.offset, 
        y: this.props.availableHeight  - this.props.height}
      )
    );
  }
});

var XAxis = React.createClass({displayName: 'XAxis',

  componentDidMount: function() {
    this._renderAxis(this.props);
  },

  componentWillReceiveProps: function(props) {
    this._renderAxis(props);
  },

  _renderAxis: function(props) {
    var xAxis = d3.svg.axis()
      .scale(props.xScale)
      .orient("bottom");

    var node = this.refs.barxaxis.getDOMNode();

    d3.select(node)
      .attr("class", "barx axis")
      .call(xAxis);

    // Style each of the tick lines
    d3.select('.barx.axis')
      .selectAll('line')
      .attr("shape-rendering", "crispEdges")
      .attr("stroke", "#000");

    // Style the main axis line
    d3.select('.barx.axis')
      .select('path')
      .attr("shape-rendering", "crispEdges")
      .attr("fill", "none")
      .attr("stroke", "none")

  },

  render: function() {
    var t = "translate(0," + this.props.height + ")"
    return (
      React.createElement("g", {
        ref: "barxaxis", 
        className: "barx axis", 
        transform: t
      }
      )
    );
  }

});


var YAxis = React.createClass({displayName: 'YAxis',

  componentDidMount: function() {
    this._renderAxis(this.props);
  },

  componentWillReceiveProps: function(props) {
    this._renderAxis(props);
  },

  _renderAxis: function(props) {
    var yAxis = d3.svg.axis()
      .ticks(props.yAxisTickCount)
      .scale(props.yScale)
      .orient("left");

    var node = this.refs.baryaxis.getDOMNode();

    d3.select(node)
      .attr("class", "bary axis")
      .call(yAxis);

    // Style each of the tick lines
    d3.selectAll('.bary.axis')
      .selectAll('line')
      .attr("shape-rendering", "crispEdges")
      .attr("stroke", "#000");

    // Style the main axis line
    d3.selectAll('.bary.axis')
      .select('path')
      .attr("shape-rendering", "crispEdges")
      .attr("fill", "none")
      .attr("stroke", "#000")

  },

  render: function() {
    return (
      React.createElement("g", {
        ref: "baryaxis", 
        className: "bary axis"
      }
      )
    );
  }

});

var DataSeries = React.createClass({displayName: 'DataSeries',

  propTypes: {
    fill: React.PropTypes.string,
    title: React.PropTypes.string,
    padding: React.PropTypes.number,
    width: React.PropTypes.number,
    height: React.PropTypes.number,
    offset: React.PropTypes.number
  },

  getDefaultProps: function() {
    return {
      padding: 0.1,
      data: []
    }
  },

  render: function() {
    var props = this.props;

    var xScale = d3.scale.ordinal()
      .domain(d3.range(props.values.length))
      .rangeRoundBands([0, this.props.width], this.props.padding);

    var bars = props.values.map(function(point, i) {
      return (
        React.createElement(Bar, {height: props.yScale(0) - props.yScale(point), width: xScale.rangeBand(), offset: xScale(i), availableHeight: props.height, fill: props.fill, key: i})
      )
    });

    return (
      React.createElement("g", null, bars)
    );
  }
});

var BarChart = React.createClass({displayName: 'BarChart',

  propTypes: {
    data: React.PropTypes.array,
    yAxisTickCount: React.PropTypes.number,
    width: React.PropTypes.number,
    margins: React.PropTypes.object,
    height: React.PropTypes.number,
    fill: React.PropTypes.string,
    title: React.PropTypes.string
  },

  getDefaultProps: function() {
    return {
      data: [],
      yAxisTickCount: 4,
      width: 500,
      height: 200,
      margins: {top: 20, right: 30, bottom: 30, left: 30},
      fill: "#3182bd",
      title: ''
    }
  },

  render: function() {

    var values = _.pluck(this.props.data, 'value');

    var labels = _.pluck(this.props.data, 'label');

    var margins = this.props.margins;

    var sideMargins = margins.left + margins.right;
    var topBottomMargins = margins.top + margins.bottom;

    var yScale = d3.scale.linear()
      .domain([0, d3.max(values)])
      .range([this.props.height - topBottomMargins, 0]);

    var xScale = d3.scale.ordinal()
        .domain(labels)
        .rangeRoundBands([0, this.props.width - sideMargins], 0.1);

    var trans = "translate(" + margins.left + "," + margins.top + ")";

    return (
      React.createElement(Chart, {width: this.props.width, height: this.props.height, title: this.props.title}, 
        React.createElement("g", {transform: trans}, 
          React.createElement(DataSeries, {
            values: values, 
            yScale: yScale, 
            xScale: yScale, 
            margins: margins, 
            data: this.props.data, 
            width: this.props.width - sideMargins, 
            height: this.props.height - topBottomMargins, 
            fill: this.props.fill}
          ), 
          React.createElement(YAxis, {
            yScale: yScale, 
            margins: margins, 
            yAxisTickCount: this.props.yAxisTickCount, 
            width: this.props.width - sideMargins, 
            height: this.props.height - topBottomMargins}
          ), 
          React.createElement(XAxis, {
            xScale: xScale, 
            data: this.props.data, 
            margins: margins, 
            width: this.props.width - sideMargins, 
            height: this.props.height - topBottomMargins}
          )
        )
      )
    );
  }

});

exports.BarChart = BarChart;

==> react-d3-0.1.6.tgz: package/barchart.js <==
'use strict';

var React = require('react');
var d3 = require('d3');
var common = require('./common');
var Chart = common.Chart;
var XAxis = common.XAxis;
var YAxis = common.YAxis;
var _ = require('lodash');


var Bar = React.createClass({displayName: 'Bar',

  propTypes: {
    fill: React.PropTypes.string,
    width: React.PropTypes.number,
    height: React.PropTypes.number,
    offset: React.PropTypes.number
  },

  getDefaultProps: function() {
    return {
      offset: 0
    };
  },

  render: function() {
    return (
      React.createElement("rect", {
        fill: this.props.fill, 
        width: this.props.width, 
        height: this.props.height, 
        x: this.props.offset, 
        y: this.props.availableHeight  - this.props.height}
      )
    );
  }
});

var DataSeries = React.createClass({displayName: 'DataSeries',

  propTypes: {
    fill: React.PropTypes.string,
    title: React.PropTypes.string,
    padding: React.PropTypes.number,
    width: React.PropTypes.number,
    height: React.PropTypes.number,
    offset: React.PropTypes.number
  },

  getDefaultProps: function() {
    return {
      padding: 0.1,
      data: []
    };
  },

  render: function() {
    var props = this.props;

    var xScale = d3.scale.ordinal()
      .domain(d3.range(props.values.length))
      .rangeRoundBands([0, this.props.width], this.props.padding);

    var bars = props.values.map(function(point, i) {
      return (
        React.createElement(Bar, {height: props.yScale(0) - props.yScale(point), width: xScale.rangeBand(), offset: xScale(i), availableHeight: props.height, fill: props.fill, key: i})
      );
    });

    return (
      React.createElement("g", null, bars)
    );
  }
});

var BarChart = React.createClass({displayName: 'BarChart',

  propTypes: {
    data: React.PropTypes.array,
    yAxisTickCount: React.PropTypes.number,
    width: React.PropTypes.number,
    margins: React.PropTypes.object,
    height: React.PropTypes.number,
    fill: React.PropTypes.string,
    title: React.PropTypes.string
  },

  getDefaultProps: function() {
    return {
      data: [],
      yAxisTickCount: 4,
      width: 500,
      height: 200,
      margins: {top: 20, right: 30, bottom: 30, left: 30},
      fill: "#3182bd",
      title: ''
    };
  },

  render: function() {

    var values = _.pluck(this.props.data, 'value');

    var labels = _.pluck(this.props.data, 'label');

    var margins = this.props.margins;

    var sideMargins = margins.left + margins.right;
    var topBottomMargins = margins.top + margins.bottom;

    var yScale = d3.scale.linear()
      .domain([d3.min([d3.min(values), 0]), d3.max(values)])
      .range([this.props.height - topBottomMargins, 0]);

    var xScale = d3.scale.ordinal()
        .domain(labels)
        .rangeRoundBands([0, this.props.width - sideMargins], 0.1);

    var trans = "translate(" + margins.left + "," + margins.top + ")";

    return (
      React.createElement(Chart, {width: this.props.width, height: this.props.height, title: this.props.title}, 
        React.createElement("g", {transform: trans}, 
          React.createElement(DataSeries, {
            values: values, 
            yScale: yScale, 
            xScale: yScale, 
            margins: margins, 
            data: this.props.data, 
            width: this.props.width - sideMargins, 
            height: this.props.height - topBottomMargins, 
            fill: this.props.fill}
          ), 
          React.createElement(YAxis, {
            yAxisClassName: "bar y axis", 
            yScale: yScale, 
            margins: margins, 
            yAxisTickCount: this.props.yAxisTickCount, 
            width: this.props.width - sideMargins, 
            height: this.props.height - topBottomMargins}
          ), 
          React.createElement(XAxis, {
            xAxisClassName: "bar x axis", 
            xScale: xScale, 
            data: this.props.data, 
            margins: margins, 
            width: this.props.width - sideMargins, 
            height: this.props.height - topBottomMargins}
          )
        )
      )
    );
  }

});

exports.BarChart = BarChart;
